/***********************************************************************
 
  This program creates a (Full backup) of your E: partition in the  
  directory 'x:\RsyncBackup\Backups\Local\Partitions\E' using rsync.exe.
 
  Greggory Shaw, USA, Nov 2016


  This script serves as a template for RsyncBackup. Make a copy of 
  this program to User_Scripts diectory, then modify to suit your needs.

  This script uses the --delete option, so be sure that you understand
  that the --delete option makes a complete backup and syncs the source 
  and destination directories. 

  If you delete something in the source directory, it gets deleted in 
  the destination directory (so be careful) on the next run.

  
  *** WARNING - NEVER USE (--delete) ON ROOT (\)    *** WARNING ***

  
  REMEMBER: to remove the '--dry-run' option to ENABLE actual changes.

 
 *** DO NOT MODIFY (UPGRADING WILL OVERWRITE), COPY TO USER_SCRIPTS  ***
 ***********************************************************************/


Call RxFuncAdd 'SysLoadFuncs','RexxUtil','SysLoadFuncs'
Call SysLoadFuncs

Version='1.1'

CurrentDir = directory()

parse var CurrentDir NewDir "\Local_Scripts" . 
BackupDir = NewDir || '\Backups\Local\Partitions\E'


/***********************************************************************
 * Directory to backup !!                                              *
                                                                       */
BackupDirectory='E:\'


/***********************************************************************
                                                                       *
   Location where the backup will be saved, directory must exist!      *
                                                                       *
   WARNING - DO NOT USE (--delete) ON A ROOT DIRECTORY - WARNING       *
                                                                       *
   Example:                                                            *
                                                                       *
   Setting the value of 'BackupLocation=D:\' will DELETE EVERYTHING    *
   ON DRIVE D: FIRST, then copy the directory.                         *
                                                                       *
   This is why I have it set to: \..\RsyncBackup\Backups\Partitions\E  *
                                                                       */

BackupLocation=BackupDir /*** DO NOT SET THIS TO ROOT (\)              */




/***********************************************************************
 * excludes file - per line of files to exclude                        *
                                                                       */
 
FilterList = '--filter=._filters.e ' 


/***********************************************************************
 * Options for Rsync & Banner                                          *
                                                                       */

opts = ' --dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during '
logs = '--log-file=%LOGFILES%\rsync.log '

CALL CColor
CALL Banner


/***********************************************************************
 * Now for the actual transfer !                                       *
 ***********************************************************************/

rsync || opts || FilterList || logs || BackupDirectory || ' ' || BackupLocation 

say ''
say 'Done!'

"pause"

EXIT 0;


CColor:

/***********************************************************************
 * Set some colors, thanx to Dmitry A.Steklenev for the inspiration    *
 * enable ANSI extended screen and keyboard control                    *
                                                                       */
'@ansi on > nul'
color.brown   = "1B"x"[0;33m"
color.red     = "1B"x"[1;31m"
color.green   = "1B"x"[1;32m"
color.yellow  = "1B"x"[1;33m"
color.blue    = "1B"x"[1;34m"
color.magenta = "1B"x"[1;35m"
color.cyan    = "1B"x"[1;36m"
color.white   = "1B"x"[1;37m"
color.gray    = "1B"x"[0m"

RETURN

Banner:

/***********************************************************************/ 

say color.gray  || 'Thank you for using '|| color.magenta || 'RsyncBackup' ||,
color.gray || ', a backup tool for your Os2/eCs system.'
say ''
say color.cyan || 'Version 'Version || color.gray || ' - 21 Nov 2016, ' || color.gray  || 'Copyright (c) 2016 by '|| color.green || 'Greggory Shaw'
say ''

say color.gray || 'This program creates a (Full backup) of your ' || color.green || BackupDirectory || color.gray || ' partition using Rsync.' 
say ''
say color.gray || 'It will synchronizes both directories, meaning that if the original is' 
say 'deleted the backup file will also be deleted on the next run.'

say ''
say 'The Rsync commandline:'
say ''
say 'Rsync ' || color.green || opts || FilterList || logs || BackupDirectory || ' ' || BackupLocation || color.gray

say ''
say 'The files will be located in: '
say  color.green || BackupDir || color.gray
say ''
say color.green || 'Note:' || color.gray || ' Some files say may not get transfered (locked or extended attributes),'
say '      if partition is booted or in use.'
say ''
say color.red || 'Continue? Y/n' || color.gray

pull YesNo
if \ (YesNo = "Y") then exit

RETURN
