/***********************************************************************
 
  Rexx-program generating a copy of multiple directories
  using rsync.exe
 
  Greggory Shaw, USA, Nov 2016
 
  This script serves as a template for RsyncBackup. Make a copy of 
  this program to User_Scripts diectory, then modify to suit your needs.


  Change the directories that you want to COPY.


      BackupDirectory='E:\Data E:\Home E:\Programs E:\Projects'
 

  Change 'BackupDir' to your desired backup location .

      BackupLocation=BackupDir


  USAGE: stand alone or remove the statement, 'Call Banner' for 
  automated backups with a scheduler.


  REMEMBER: remove the --dry-run option to ENABLE actual changes. 


 *** DO NOT MODIFY (UPGRADING WILL OVERWRITE), COPY TO USER_SCRIPTS  ***

 ***********************************************************************/


Call RxFuncAdd 'SysLoadFuncs','RexxUtil','SysLoadFuncs'
Call SysLoadFuncs

Version='1.1'

CurrentDir = directory()

parse var CurrentDir NewDir "\Local_Scripts" . 
BackupDir = NewDir || '\Backups\Local\Copy'


/***********************************************************************
 * Directory to backup !!                                              *
                                                                       */

BackupDirectory='E:\Data E:\Home E:\Programs E:\Projects'


/***********************************************************************
 * Where should the backup be saved? This directory must exist!!       *
                                                                       */
BackupLocation=BackupDir


/***********************************************************************
 * excludes file - per line of files to exclude                        *
                                                                       */
FilterList = '--filter=._filters.list ' 


/***********************************************************************
 * Options for Rsync                                                   *
                                                                       */
opts = ' --dry-run --archive --itemize-changes --os2-perms --stats --xattrs '
logs = '--log-file=%LOGFILES%\rsyncd.log '

Call CColor
Call Banner


/***********************************************************************
 * Now for the actual transfer !                                       *
 ***********************************************************************/

rsync || opts || FilterList || logs || BackupDirectory || ' ' ||BackupLocation 

say ''
say 'Done!'

"pause"

EXIT 0;


CColor:

/***********************************************************************
 * Set some colors, thanx to Dmitry A.Steklenev for the inspiration    *
 * enable ANSI extended screen and keyboard control                    *
                                                                       */
'@ansi on > nul'
color.brown   = "1B"x"[0;33m"
color.red     = "1B"x"[1;31m"
color.green   = "1B"x"[1;32m"
color.yellow  = "1B"x"[1;33m"
color.blue    = "1B"x"[1;34m"
color.magenta = "1B"x"[1;35m"
color.cyan    = "1B"x"[1;36m"
color.white   = "1B"x"[1;37m"
color.gray    = "1B"x"[0m"

RETURN

Banner:

/***********************************************************************/ 

say color.gray  || 'Thank you for using '|| color.magenta || 'RsyncBackup' ||,
color.gray || ', a backup tool for your Os2/eCs system.'
say ''
say color.cyan || 'Version 'Version || color.gray || ' - 21 Nov 2016, ' || 'Copyright (c) 2016 by '|| color.green || 'Greggory Shaw'

say ''
say color.gray || "This program creates a 'COPY' of the " || color.green ||,
BackupDirectory
say color.gray  || 'directories using Rsync.'

say ''
say 'The Rsync commandline:'
say ''
say 'Rsync ' || color.green || opts || FilterList || logs || BackupDirectory || ' ' || BackupLocation || color.gray

say ''
say 'The files will be located in: '
say  color.green || BackupDir || color.gray
say ''
say color.green || 'Note:' || color.gray || ' Some files say may not get transfered (locked or extended attributes),'
say '      if partition is booted or in use.'
say ''
say color.red || 'Continue? Y/n' || color.gray

pull YesNo
if \ (YesNo = "Y") then exit

RETURN