/***********************************************************************

 This program makes a backup of the U: partition over the network to the
 directory x:\RsyncBackup\Backups\Network\Workstation001\Partitions\W.
 
 Greggory Shaw, USA, Nov 2016
 
 
 This script serves as a template for RsyncBackup. Make a copy of 
 this program to User_Scripts diectory, then modify to suit your needs.

 
 *** IMPORTANT *** IMPORTANT *** IMPORTANT ***

 The following entry is needed in rsyncd.conf on the rsync server:
 
      [RsyncComputer]
      #    Hosts allow "/24" specifies the entire subnet mask 
      #    hosts allow = 192.168.1.0/24
      comment = Rsync backup storage area
      path = x:/RsyncBackup/Backups/Network
      read only = false
      list = yes
      gid = root
      uid = root


 USAGE: stand alone or remove the statement, 'Call Banner' for 
 automated backups with a scheduler.

 REMEMBER: to remove the '--dry-run' option to ENABLE actual changes.


 *** DO NOT MODIFY (UPGRADING WILL OVERWRITE), COPY TO USER_SCRIPTS  ***
 
 ***********************************************************************/


Call RxFuncAdd 'SysLoadFuncs','RexxUtil','SysLoadFuncs'
Call SysLoadFuncs

Version='1.1'
CurrentDir = directory()


/***********************************************************************
 * Drive to backup !!                                                  *
                                                                       */
BackupDir= ' W:\'


/***********************************************************************
 * What module should Rsync use on the server                          *
                                                                       */
ServerMod='RsyncBackup'


/***********************************************************************
 * Where should the backup be saved?                                   *
                                                                       */
ServerDir='WS001\Partitions\W'


/***********************************************************************
 * The name of the Rsync backup server                                 *
                                                                       */
BackupServer= 192.168.1.100


/***********************************************************************
 * excludes file - per line of files to exclude                        *
                                                                       */
 
FilterList = ' --filter=._filters.w' 


/***********************************************************************
 * Options for Rsync & Banner                                          *
                                                                       */
Opts = ' --dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --delete-excluded'
Logs = ' --log-file=%LOGFILES%\rsyncd.log'
Skip = ' --skip-compress=7z/aac/ace/arc/arj/arw/asf/avi/bz2/cab/dat/flac/flv/gif/gz/iso/jar/jp2/jpeg/jpg/lz/lzma/lzo/m4a/m4p/mpv/mkv/mos/mov/mp3/mp4/mpeg/mpg/msi/nef/oga/ogg/ogv/pef/png/qt/rar/rpm/rw2/rzip/s7z/sfx/sr2/srf/svgz/tgz/vob/wim/wma/wmv/xz/zip'

CALL CColor
CALL Banner


/***********************************************************************
 * Now for the actual transfer !                                       *
                                                                       */

rsync || Opts || FilterList || Logs || BackupDir || ' ' || BackupServer ||"::" || ServerMod || '\' || ServerDir 

say ''
say 'Done!'

"pause"

EXIT 0;


CColor:

/***********************************************************************
 * Set some colors, thanx to Dmitry A.Steklenev for the inspiration    *
 * enable ANSI extended screen and keyboard control                    *
                                                                       */

'@ansi on > nul'
color.brown   = "1B"x"[0;33m"
color.red     = "1B"x"[1;31m"
color.green   = "1B"x"[1;32m"
color.yellow  = "1B"x"[1;33m"
color.blue    = "1B"x"[1;34m"
color.magenta = "1B"x"[1;35m"
color.cyan    = "1B"x"[1;36m"
color.white   = "1B"x"[1;37m"
color.gray    = "1B"x"[0m"

RETURN


Banner:

/***********************************************************************/ 

say color.gray  || 'Thank you for using '|| color.magenta || 'RsyncBackup' ||,
color.gray || ', a backup tool for your Os2/eCs system.'
say ''
say color.cyan || 'Version 'Version || color.gray || ' - 21 Nov 2016, ' || 'Copyright (c) 2016 by ' || color.green || 'Greggory Shaw'

say ''
say color.gray || 'This program creates a backup of your ' || color.green || BackupDir || color.gray || ' partition on a central' 
say 'backup server using Rsync.'
say ""
say "The 'BackupServer' value needs to be changed to the IP address "
say 'of your server currently set to: ' || color.green || BackupServer || color.gray

say ''
say 'The Rsync commandline:'
say ''
say 'Rsync ' || color.green || Opts || Logs || BackupDir || ' ' || BackupServer ||"::" || ServerMod || '\' || ServerDir || color.gray

say ""
say 'The files will be located in: '
say  color.green || 'Rsyncbackup\Backups\Network\' || ServerDir || color.gray
say ''
say color.green || 'Note:' || color.gray || ' Some files say may not get transfered (locked or extended attributes),'
say '      if partition is booted or in use.'
say ''

say color.red || 'Continue? y/n' || color.gray

pull YesNo
if \ (YesNo = "Y") then exit

RETURN


