/***********************************************************************
 
  Rexx-program generating a copy of multiple directories using rsync.exe
 
  Greggory Shaw, USA, July 2016
 
  This script serves as a template for RsyncBackup. Make a copy of 
  this program to User_Scripts diectory, then modify to suit your needs.


  Change the directories that you want to COPY.


      BackupDirectory='E:\Data E:\Home E:\Programs E:\Projects'
 

  Change 'BackupDir' to your desired backup location .

      BackupLocation=BackupDir


  USAGE: stand alone or remove the statement, 'Call Banner' for 
  automated backups with a scheduler.

  REMEMBER: remove the --dry-run option to ENABLE actual changes. 


 *** DO NOT MODIFY (UPGRADING WILL OVERWRITE), COPY TO USER_SCRIPTS  ***

 ***********************************************************************/


Call RxFuncAdd 'SysLoadFuncs','RexxUtil','SysLoadFuncs'
Call SysLoadFuncs

Version='0.8'

CurrentDir = directory()


/***********************************************************************
 * Directory to backup !!                                              *
                                                                       */

BackupDirectory=' E:\Data E:\Home E:\Programs E:\Projects'


/***********************************************************************
 * What module should Rsync use on the server                          *
                                                                       */
ServerMod='RsyncBackup'


/***********************************************************************
 * Where should the backup be saved?                                   *
                                                                       */
ServerDir='WS001\Copy'


/***********************************************************************
 * The name of the Rsync backup server                                 *
                                                                       */
BackupServer= 192.168.1.100


/***********************************************************************
 * excludes file - per line of files to exclude                        *
                                                                       */
FilterList = ' --filter=._filters.list' 


/***********************************************************************
 * Options for Rsync                                                   *
                                                                       */
Opts = ' --dry-run --archive --itemize-changes --os2-perms --stats --xattrs'
Logs = ' --log-file=%LOGFILES%\rsyncd.log'
Skip = ' --skip-compress=7z/aac/ace/arc/arj/arw/asf/avi/bz2/cab/dat/flac/flv/gif/gz/iso/jar/jp2/jpeg/jpg/lz/lzma/lzo/m4a/m4p/mpv/mkv/mos/mov/mp3/mp4/mpeg/mpg/msi/nef/oga/ogg/ogv/pef/png/qt/rar/rpm/rw2/rzip/s7z/sfx/sr2/srf/svgz/tgz/vob/wim/wma/wmv/xz/zip'

Call CColor
Call Banner


/***********************************************************************
 * Now for the actual transfer !                                       *
 ***********************************************************************/

rsync || opts || FilterList || logs || BackupDirectory || ' ' ||BackupLocation 

say ''
say 'Done!'

"pause"

EXIT 0;


CColor:

/***********************************************************************
 * Set some colors, thanx to Dmitry A.Steklenev for the inspiration    *
 * enable ANSI extended screen and keyboard control                    *
                                                                       */
'@ansi on > nul'
color.brown   = "1B"x"[0;33m"
color.red     = "1B"x"[1;31m"
color.green   = "1B"x"[1;32m"
color.yellow  = "1B"x"[1;33m"
color.blue    = "1B"x"[1;34m"
color.magenta = "1B"x"[1;35m"
color.cyan    = "1B"x"[1;36m"
color.white   = "1B"x"[1;37m"
color.gray    = "1B"x"[0m"

RETURN

Banner:

/***********************************************************************/ 

say color.gray  || 'Thank you for using '|| color.magenta || 'RsyncBackup' ||,
color.gray || ', a backup tool for your Os2/eCs system.'
say ''
say color.cyan || 'Version 'Version || color.gray || ' - 16 March 2014'
say ''
say color.gray || 'This Program is released under the Gnu Public Licence',
|| '(GPL).'
say 'See the file COPYING for further information.'
say color.gray  || 'Copyright (c) 2012 by '|| color.green || 'Greggory Shaw'
say ''
say color.gray || "This program creates a 'COPY' of the " || color.green ||,
BackupDirectory
say color.gray  || 'directories using Rsync.'
say ''
say 'The files will be located in: '
say  color.green || 'Rsyncbackup\Backups\Network\' || ServerDir || color.gray
say ''
say ''
say color.red || 'Continue? y/n' || color.gray

pull YesNo
if \ (YesNo = "Y") then exit

RETURN