/************************************************************************

 This REXX script will install the RsyncBackup/2 folder object on your
 WPS desktop. The folder object will have the WPS ID <RsyncBackupFolder>.

 This script checks if the folder already exist. If it does then it will
 be automatically updated rather than replaced and a shadow will be
 created on the desktop if necessary.

 Copyright (c) 2016 by Greggory Shaw, RysncBackup/2 v1.1, 21 Nov 2016

 ************************************************************************/


call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs'
call SysLoadFuncs

/* RxLvmLoadFuncs:
 *   Register all RXLVM.DLL functions.  Returns ''.
 */
CALL RxFuncAdd 'RxLvmLoadFuncs', 'RXLVM', 'RxLvmLoadFuncs'
CALL RxLvmLoadFuncs


/* RxLvmVersion:
 *   Retrieve the current RXLVM.DLL version.  Returns the version string
 *   'x.y.z' (where x, y, and z are each a number with one or more digits).
 */
PARSE VALUE RxLvmVersion() WITH major '.' minor '.' refresh
SAY 'Current RXLVM.DLL version is' major'.'minor 'refresh level' refresh
SAY


/* RxLvmRediscoverPRM:
 *   Refresh removeable media.  Returns ''.
 */

CALL CHAROUT, 'Discovering removeable media... '
disc = RxLvmRediscoverPRM()

IF disc == '' THEN
    SAY 'done'

ELSE DO
    PARSE VAR disc 'ERROR: ' lvm_error
    IF lvm_error \= '' THEN SAY 'LVM.DLL returned error code' lvm_error
END
SAY


/* RxLvmEngineOpen:
 *   Open the LVM Engine (required for all other LVM functions except
 *   RxLvmRediscoverPRM).  Returns ''.
 */
open = RxLvmEngineOpen()

IF open == '' THEN
    SAY 'Opened LVM Engine successfully.'

ELSE DO
    PARSE VAR open 'ERROR: ' lvm_error
    IF lvm_error \= '' THEN SAY 'LVM.DLL returned error code' lvm_error
    RETURN lvm_error
END

/***************************************************************************/

Date = '11.21.2016'
Version='1.1'


 SIGNAL ON HALT

 TitleLine = STRIP(SUBSTR(SourceLine(2), 3));
 PARSE VAR TitleLine CmdName'.CMD 'Info
 Title     = CmdName Info

 env          = 'OS2ENVIRONMENT';
 TRUE         = (1 = 1);
 FALSE        = (0 = 1);
 Redirection  = '> NUL 2>&1';
 '@ECHO OFF'

 /* OS/2 errorcodes */
 ERROR.NO_ERROR           =  0;
 ERROR.INVALID_FUNCTION   =  1;
 ERROR.FILE_NOT_FOUND     =  2;
 ERROR.PATH_NOT_FOUND     =  3;
 ERROR.ACCESS_DENIED      =  5;
 ERROR.NOT_ENOUGH_MEMORY  =  8;
 ERROR.INVALID_FORMAT     = 11;
 ERROR.INVALID_DATA       = 13;
 ERROR.NO_MORE_FILES      = 18;
 ERROR.WRITE_FAULT        = 29;
 ERROR.READ_FAULT         = 30;
 ERROR.GEN_FAILURE        = 31;
 ERROR.INVALID_PARAMETER  = 87;

 GlobalVars = 'Title CmdName env TRUE FALSE Redirection ERROR.';
 SAY;
 SAY Title;
 SAY;


BootDrive = OS2BootDrive()
env = 'ENVIRONMENT'


HomePath = VALUE( 'HOME',, env )
if length( HomePath ) = 0 then
    HomePath = OSBootDrive()'\Home'


CALL ColorPage
CALL Banner

theSelect=getSelection()

SELECT
  WHEN theSelect=1 THEN DO 
	SAY ""
	call InstallFull
        Exit 0;
  END
  WHEN theSelect=2 THEN DO
	SAY ""
	call InstallClient
        Exit 0;
  END
  WHEN theSelect=3 THEN DO
	SAY ""
	call InstallServer
        Exit 0;
  END
  WHEN theSelect=4 THEN DO
	SAY ""
        call mPlayerAdv
  END
OTHERWISE
	NOP
END

Exit 0;



getSelection: PROCEDURE

QUIT=0
SAY "Select option:"
SAY ""
SAY "    1: Full Install of RsyncBackup/2"
SAY ""
SAY "    2: Client only"
SAY "    3: Server only"
SAY ""
SAY "    ('h' for help)"
SAY "    ('q' for exit)"
SAY ""
Do UNTIL QUIT=1
  say '>'
  parse value SysCurPos() with aktzeile aktspalte
  newposition=SysCurPos(aktzeile-1,2)
  pull theChar
  IF theChar='H' then call mPlayerHelp
  IF theChar='Q' then EXIT 1
  if LENGTH(theChar)==1 & VERIFY(theChar, "1234")==0 THEN QUIT=1
  ELSE
   call beep 100, 100
  call SysCurPos aktzeile-1, 0
  SAY "1B"x || "[K"
  call SysCurPos aktzeile-1, 0
END
  SAY ""
RETURN theChar


say ""
say "-----------------------------------------------------------------------------"
say ""
say "RsyncBackup Installation Utility"
say ""
say "Do you want to install the RsyncBackup objects to your Desktop (Y or n)?"
say ""

key = SysGetKey('NOECHO')
parse upper var key key
if key == 'N' then call dont_install
call install

dont_install:
say "Installation was canceled."
call end

install:
say "Creating or updating the RsyncBackup program objects..."


call ProgramObj

EXIT 0;


ColorPage:

/***********************************************************************
 *  Set some colors, thanx to Dmitry A.Steklenev for the inspiration    
 *  enable ANSI extended screen and keyboard control                    
 */

'@ansi on > nul'
color.brown   = "1B"x"[0;33m"
color.red     = "1B"x"[1;31m"
color.green   = "1B"x"[1;32m"
color.yellow  = "1B"x"[1;33m"
color.blue    = "1B"x"[1;34m"
color.magenta = "1B"x"[1;35m"
color.cyan    = "1B"x"[1;36m"
color.white   = "1B"x"[1;37m"
color.gray    = "1B"x"[0m"

RETURN




Banner:

/***********************************************************************
 *  Startup Message                                                     
 */

say color.gray  || 'Thank you for using '|| color.magenta || 'RsyncBackup/2' ||,
color.gray || ' an automated tool for OS2/eCs'
say ''
say 'Version ' || Version || ' -- ' || Date || ', Copyright (c) 2016 by '|| color.white ||,
'Greggory Shaw'

say ''
say ''
say color.gray  || 'Default option will install the full version of ' || color.green  || 'RsyncBackup/2.' || color.gray

say ''
say '(best if you are unsure if you need the networking functions.)'
say ''
say ''
say ''
say ''

RETURN


/************************************************************************
 *  Full Installation of RsyncBackup/2                                                     
 */

InstallFull:

cls
say 'Installing RsyncBackup/2 - Full installation'
say '---------------------------------------------'

address cmd 'copy Config\rsync.exe '   || BootDrive || '\mptn\bin\rsync.exe';
address cmd 'copy Config\rsyncd.motd ' || BootDrive || '\mptn\etc\rsyncd.motd';

say ''
say "Creating or updating main RsyncBackup/2 objects"
say '------------------------------------------------'
say 'Main folder:'
say ''

Directory = directory()

cRsync = Directory
dRsync = Directory || '\Backups'


/************************************************************************

               First, create the 'Rsync folder' object.
 
 ************************************************************************/

type="WPFolder"
title="RsyncBackup"
folder="<WP_DESKTOP>"
objid="<RSYNC_BACKUP>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";PARAMETERS=--daemon;ICONFILE="Directory"\Icons\network1.ICO;ICONNFILE=1,"Directory"\Icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Rsync Backup Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Rsync Backup Folder Shadow Object already exists!"
   end
end

/************************************************************************
 * Create or update the README 1ST object.
 */

type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs\readme.1st;"
if SysCreateObject(type, "readme.1st", folder, params, "replace") then
   say "readme.1st Shadow Object successfully created."
else do
   say "Failed on create the readme.1st Shadow Object!"
   call end
end

/************************************************************************
 * Create or update the QUICKSTART.TXT object.
 */

type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs\quickstart.txt;"
if SysCreateObject(type, "quickstart.txt", folder, params, "replace") then
   say "quickstart.txt Shadow Object successfully created."
else do
   say "quickstart.txt on create the quickstart.txt Shadow Object!"
   call end
end


/************************************************************************

                          Backups Folder                                        

 ************************************************************************/

 type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\Backups;"
if SysCreateObject(type, "Backups", folder, params, "replace") then
   say "Docs directory Shadow Object successfully created."
else do
   say "Failed on create the Docs Shadow Object!"
   call end
end


/************************************************************************

                            Backup Boot Folder 

 ************************************************************************/

type="WPFolder"
title="Backup Boot"
folder="<RSYNC_BACKUP>"
objid="<BackupBootFolder>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\zipped_files1.ICO;ICONNFILE=1,"Directory"\icons\zipped_files2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "ZipBoot Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "ZipBoot Folder Shadow Object already exists!"
   end
end

/************************************************************************
 * Create or update the ZipBootdrive program object
 */

type="WPProgram"
title="Zip Boot-Drive"
objid="<ZipBoot>"
folder="<BackupBootFolder>"
params="PROGTYPE=PM;EXENAME="Directory"\ZipBoot\ZipBoot.cmd;STARTUPDIR="Directory"\ZipBoot;OBJECTID="objid";ICONFILE="Directory"\icons\compress.ico;"
if SysCreateObject(type, title, folder, params, "update") then
   say "ZipBootdrive Program Object successfully created."
else do
   say "Failed on create the ZipBootdrive Program Object!"
   call end
end


/************************************************************************

                          Docs Directory Folder                                        

 ************************************************************************/

 type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs;"
if SysCreateObject(type, "docs", folder, params, "replace") then
   say "Docs directory Shadow Object successfully created."
else do
   say "Failed on create the Docs Shadow Object!"
   call end
end


/************************************************************************

                          Rsync Server Folder                                        

 ************************************************************************/

say ''
type="WPFolder"
title="Rsync Server"
folder="<RSYNC_BACKUP>"
objid="<Rsync_Server>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\Icons\network3.ICO;ICONNFILE=1,"Directory"\Icons\network4.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Rsync Server Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Rsync Server Folder Shadow Object already exists!"
   end
end

/************************************************************************
 * Create or update the Rsync Server program object
 */

type="WPProgram"
title="Rsync Server"
objid="<RsyncProgram>"
folder="<Rsync_Server>"
params="PROGTYPE=PM;EXENAME="BootDrive"\mptn\bin\rsync.exe;PARAMETERS=--daemon --config="Directory"\Config\rsyncd.conf --log-file="BootDrive"\var\log\rsyncd.log;OBJECTID="objid";STARTUPDIR="BootDrive"\mptn\bin;ICONFILE="Directory"\icons\system.ICO;"
if SysCreateObject(type, title, folder, params, "update") then
   say "Rsync Server Object successfully created."
else do
   say "Failed on create the Rsync Program Object!"
   call end
end

/************************************************************************
 * Create or update the edit rsyncd.conf program object
 */

type="WPProgram"
title="edit rsyncd.conf"
objid="<RsyncEdit>"
folder="<Rsync_Server>"
params="PROGTYPE=PM;EXENAME=e.exe;PARAMETERS="cRsync"\Config\rsyncd.conf;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Rsync Config Object successfully created."
else do
   say "Failed on create the Rsync Program Object!"
   call end
end

/************************************************************************
 * Create or update the rsyncd.log program object
 */

type="WPShadow"
folder="<Rsync_Server>"
params="SHADOWID="BootDrive"\var\log\rsyncd.log"
if SysCreateObject(type, "rsyncd.log", folder, params, "replace") then
   say "rsyncd.log Shadow Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end

say ''
say "Creating RsyncBackup/2 main folder complete"
say ''

pause


/************************************************************************

            Create or update the LOCAL BACKUP FOLDER           

 ************************************************************************/

cls
say ''
say "Creating or updating LOCAL BACKUP objects"
say '------------------------------------------------'
say 'Local Backup folder:'
say ''


type="WPFolder"
title="Local Backup"
folder="<RSYNC_BACKUP>"
objid="<RS_LOCALCOPY>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\system1.ICO;ICONNFILE=1,"Directory"\icons\system2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Local Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Local copy Folder Shadow Object already exists!"
   end
end

/******* Create or update the Full folder *********/

type="WPFolder"
title="Full Copy (Sync)"
folder="<RS_LOCALCOPY>"
objid="<RsyncFullFolder>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\system1.ICO;ICONNFILE=1,"Directory"\icons\system2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Local Full Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Full Folder Shadow Object already exists!"
   end
end


/********** Create or update the Local copy scripts dir object *****/

 type="WPShadow"
folder="<RS_LOCALCOPY>"
params="SHADOWID="Directory"\Local_Scripts;"
if SysCreateObject(type, "Local_Scripts", folder, params, "replace") then
   say "Local Scripts Folder successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end

say ''


/************************************************************************

            Create or update the LOCAL FULL COPY program objects            

 ************************************************************************/


type="WPProgram"
title="Local - Full copy (Sync)"
objid="<RsyncLocalFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log "BootDrive"\var\temp "dRsync"\Local\Full;TEMPLATE=YES;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Full Program Object successfully created."
else do
   say "Failed to create the Local Full copy Program Object!"
   call end
end

type="WPProgram"
title="Local copy - Home Directory"
objid="<RsyncHomeFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log "HomePath" "dRsync"\Local\Full;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Home Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Local - Full Home Directory: copy Program Object!"
   call end
end

type="WPProgram"
title="Local copy - Data Directory"
objid="<RsyncDataFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log E:\Data "dRsync"\Local\Full;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Data Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Full Data Directory: copy Program Object!"
   call end
end

type="WPProgram"
title="Local copy - Programs Directory"
objid="<RsyncProgFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log E:\Programs "dRsync"\Local\Full;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Programs Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Local - Full Programs Directory copy Program Object!"
   call end
end

say ''

type="WPShadow"
folder="<RsyncFullFolder>"
params="SHADOWID="BootDrive"\var\log\rsync.log"
if SysCreateObject(type, "rsync.log", folder, params, "replace") then
   say "rsync.log Shadow Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end

say ''
pause


/************************************************************************

    Create or update the NETWORK BACKUP DIRECTORY objects           

 ************************************************************************/

cls
say ''
say "Creating or updating NETWORK BACKUP objects"
say '------------------------------------------------'
say 'Network Backup folder:'
say ''


type="WPFolder"
title="Network Backup"
folder="<RSYNC_BACKUP>"
objid="<NetworkFolder>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\network1.ICO;ICONNFILE=1,"Directory"\icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Network Copy Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Network copy Folder Shadow Object already exists!"
   end
end

/************************************************************************
 * Create or update the Network_scripts directory object.
 */

 type="WPShadow"
folder="<NetworkFolder>"
params="SHADOWID="Directory"\Network_scripts;ICONFILE="Directory"\icons\network1.ICO;"
if SysCreateObject(type, "Network_scripts", folder, params, "replace") then
   say "Network Scripts folder Shadow Object successfully created."
else do
   say "Failed on create the Network copy scripts Shadow Object!"
   call end
end


/******* Create or update the NETWORK FULL directory object *********/

type="WPFolder"
title="Full Copy (Sync)"
folder="<NetworkFolder>"
objid="<RsyncFullNetwork>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\network1.ICO;ICONNFILE=1,"Directory"\icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Network Full Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Full Folder Shadow Object already exists!"
   end
end

/******* Create or update the PARTITIONS folder *********/

type="WPFolder"
title="Backup Partitions"
folder="<NetworkFolder>"
objid="<PartitionsNetwork>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\network1.ICO;ICONNFILE=1,"Directory"\icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Network Partition Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end

say ''


/************************************************************************

 * Create or update the NETWORK - FULL COPY objects

 *************************************************************************/


type="WPProgram"
title="Network - Full Copy (Sync)"
objid="<RsyncNetworkNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log "BootDrive"\var\temp 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=YES;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Full Program Object successfully created."
else do
   say "Failed to create the Network - Full Program Object!"
   call end
end

type="WPProgram"
title="Network Copy - Data Directory"
objid="<RsyncDataNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run -ai --os2-perms --stats --xattrs  --delete-during --log-file=\var\log\rsync.log E:\Data 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Data Directory: Full copy program object successfully created."
else do
   say "Failed to create the Network - Data Directory: Full Copy program object!"
   call end
end

type="WPProgram"
title="Network Copy - Home Directory"
objid="<RsyncHomeNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run -ai --os2-perms --stats --xattrs  --delete-during --log-file=\var\log\rsync.log E:\Home 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Home Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Network - Home Directory: Full Copy program object!"
   call end
end

type="WPProgram"
title="Network Copy - Programs Directory"
objid="<RsyncProgNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run -ai --os2-perms --stats --xattrs  --delete-during --log-file=\var\log\rsync.log E:\Programs 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Programs Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Network - Programs Directory: Full Copy program object!"
   call end
end

say ''

type="WPShadow"
folder="<RsyncFullNetwork>"
params="SHADOWID="BootDrive"\var\log\rsync.log"
if SysCreateObject(type, "rsync.log", folder, params, "replace") then
   say "rsync.log Shadow Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end

say ''
pause


/************************************************************************

    Create or update the BACKUP PARTITION objects           

 ************************************************************************/

cls
say ''
say 'Querying the list of volumes ... '
say ''


/* RxLvmGetVolumes:
 *   Query the list of volumes.  Always returns 1.  The parameter specifies a
 *   REXX stem name which will be populated with the volume data.  stem.0
 *   contains the number of volumes, and each other stem item contains the
 *   following information:
 *   <handle> <letter> <preference> <filesystem> <size> <device> <type> <bootable> <name>
 *     <handle>     An 8-digit hexadecimal string that uniquely identifies the
 *                  volume
 *     <letter>     The volume's current drive letter, or ? if none
 *     <preference> The volume's preferred drive letter, '?' if none, or '*' if the
 *                  drive letter is not assigned by LVM
 *     <filesystem> The volume's current file system
 *     <size>       The volume's size, in MiB
 *     <device>     The volume's device type.  This will be one of:
 *                      HDD - Hard disk drive
 *                      PRM - Removeable media under LVM control
 *                      CD  - CD/DVD drive (not controlled by LVM)
 *                      LAN - LAN drive (not controlled by LVM)
 *                      ?   - Unknown non-LVM device (e.g. RAM disk)
 *     <type>       The volume type.  This will be one of:
 *                      0   - standard (i.e. "compatibility") volume
 *                      1   - advanced (i.e. "LVM") volume
 *     <bootable>   The volume's bootable flag.  This will be one of:
 *                      B   - bootable (on Boot Manager menu)
 *                      S   - startable
 *                      I   - installable
 *                      N   - none
 *     <name>       The volume's name (may contain spaces or punctuation marks)
 *
 *   Example:
 *      volumes.0 == 4
 *      volumes.1 == "FC04D5A7 C C HPFS 2047 HDD 0 B eComStation"
 *      volumes.2 == "FC04D4E7 D D FAT16 2000 HDD 0 B Maintenance"
 *      volumes.3 == "FC04C567 E E JFS 102404 HDD 1 N Applications"
 *      volumes.4 == "FC04B0C7 H * CDFS 527 CD 0 N [ CDROM 1 ]"
 */
qv = RxLvmGetVolumes("vols.")
IF LEFT( qv, 6 ) == 'ERROR:' THEN DO
    PARSE VAR qv 'ERROR: ' lvm_error
    SAY 'LVM.DLL returned error code' lvm_error
    RETURN lvm_error
END
SAY vols.0 'volumes found:'
DO i = 1 TO vols.0
    PARSE VAR vols.i vhandle vletter vpref vfilesys vsize vdevice vtype vbootable vname
    IF vletter == '?'        THEN letter = '--'
    ELSE IF vpref \= vletter THEN letter = vpref'->'vletter':'
    ELSE                          letter = vletter':'
    IF vtype == 1 THEN type = 'Advanced volume'
    ELSE               type = 'Standard volume'
    SELECT
        WHEN vbootable == 'S' THEN boot = 'Startable'
        WHEN vbootable == 'I' THEN boot = 'Installable'
        WHEN vbootable == 'B' THEN boot = 'Bootable'
        OTHERWISE                  boot = ''
    END
    SAY RIGHT( letter, 6 ) LEFT( vname, 20 ) LEFT( vfilesys, 10 ) LEFT( vsize 'MB', 14 ) vdevice ' ' boot
    SAY '      ' type '['vhandle']'

END
SAY

    pause

cls
say ''
say 'Creating the backup partitions objects'
say '--------------------------------------'
say 'Local and Network objects:'
say ''


 /* show help */
 ARG Parm .
 IF (POS('?', Parm) > 0) THEN
 DO
    rc = ShowHelp();
    EXIT(ERROR.INVALID_PARAMETER);
 END;

 /* defaults */
 GlobalVars = GlobalVars 'Partition.';
 fOpenObjects = (POS(Parm, '/BATCH') \= 1);

 /* load rexxutils */
 Call RxFuncAdd 'SysLoadFuncs','REXXUTIL','SysLoadFuncs';
 Call SysLoadFuncs;

 PARSE SOURCE . . CallName
 CallPath = LEFT( CallName, LASTPOS( '\', CallName) - 1);
 IconPath = CallPath;

 /* query system version */
 IF (SysOs2Ver() < 2.40) THEN
    FolderIconBase = IconPath'\folder3';
 ELSE
    FolderIconBase = IconPath'\folder4';

 /* determine bartitions from fdisk */
 rc = RxLvmGetVolumes("vols.")

 /* create objects */
 CALL CHAROUT, 'Creating folder for reboot objects ... ';
 rc = SysCreateObject( 'WPFolder', 'Backup Partitions', '<RS_LOCALCOPY>',  'CCVIEW=NO;OBJECTID=<RS_PARTITIONS>;ICONFILE='Directory'\Icons\system1.ICO;ICONNFILE=1,'Directory'\Icons\system2.ICO;', 'U');

 CALL CHAROUT, 'Creating program icons ... ';
 rc = SysCreateObject( 'WPProgram',  'Recreate Volume Icons ', '<RS_PARTITIONS>',  'OBJECTID=<WP_BACKUP_RECREATE>;EXENAME='CallName';PARAMETERS=/BATCH;PROGRAMTYPE=WINDOWABLEVIO;MAXIMIZED=YES;NOAUTOCLOSE=YES;', 'U');
 rc = SysCreateObject( 'WPProgram',  'Backup/2 Readme',        '<RS_PARTITIONS>',  'OBJECTID=<WP_BACKUP_VIEW_README>;CCVIEW=NO;EXENAME=E.EXE;PARAMETERS='Directory'\docs\readme_backup_partitions.txt;PROGRAMTYPE=PM;', 'U');
 SAY 'Ok.';

 /* collect ids from old reboot icons */
 OldRebootIcons = '';
 IdList = SysIni(, 'PM_Workplace:Location', 'ALL:', 'Id.');
 DO i = 1 TO Id.0
    IF (POS( '<WP_REBOOT_PART_', Id.i) = 1) THEN
       OldRebootIcons = OldRebootIcons Id.i;
 END;


 /* select partition icon */
 /* first check name */
 /* second, check partition type */
 DO i = 1 TO vols.0
    PARSE VAR vols.i vhandle vletter vpref vfilesys vsize vdevice vtype vbootable vname

    ThisPartition = TRANSLATE(vols.i);
    SELECT

       WHEN (vols.vfilesys = '83') THEN
          PartitionIcon = IconPath'\linux.ico';

       WHEN (POS('OS2', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\Icons\os2.ico';

       WHEN (POS('JFS', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\Icons\os2.ico';

       WHEN (POS('WIN', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\win.ico';

       WHEN (POS('NT', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\win.ico';

       /* assume type 7 is HPFS and not NTFS ;-) */
       WHEN (vfilesys = 'JFS') THEN
          PartitionIcon = IconPath'\Icons\os2.ico';

       OTHERWISE
          PartitionIcon = IconPath'\dos.ico';

    END;

    IF (vdevice = 'HDD') THEN
      DO 

        CALL CHAROUT, 'Creating Local backup objects for partition' vname '... ';
        Id = '<RS_PART_'TRANSLATE(TRANSLATE(vname, '_', ' '))'>';
        rc = SysCreateObject( 'WPProgram',  'Backup' '('vletter ':) ' vname , '<RS_PARTITIONS>',  'OBJECTID='Id';EXENAME=*;PARAMETERS=/C rsync --dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log 'vletter':\ 'Directory'\Backups\Local\Partitions\'vletter';PROGTYPE=WINDOWABLEVIO;MINIMIZED=YES;ICONFILE='PartitionIcon';', 'U');
    SAY 'Ok.';
      END

    IF (vdevice = 'HDD') THEN
      DO 

        CALL CHAROUT, 'Creating Netowrk backup objects for partition' vname '... ';
        Id = '<RS_NETWORK_'TRANSLATE(TRANSLATE(vname, '_', ' '))'>';
        rc = SysCreateObject( 'WPProgram',  'Network Backup' '('vletter ':) ' vname , '<PartitionsNetwork>',  'OBJECTID='Id';EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log 'vletter':\ 192.168.1.100::RsyncBackup\WS001\Partitions\'vletter';PROGTYPE=WINDOWABLEVIO;MINIMIZED=YES;ICONFILE='PartitionIcon';', 'U');
    SAY 'Ok.';
      END

    /* don't delete that one later */
    IdPos = WORDPOS( Id, OldRebootIcons);
    IF (IdPos > 0) THEN
    DO
       OldRebootIcons = DELWORD( OldRebootIcons, IdPos, 1);
    END;


 END;

 /* delete old reboot icons */
 IF (WORDS( OldRebootIcons) > 0) THEN
 DO

    CALL CHAROUT, 'Deleting obsolete program icons ... ';
    DO i = 1 TO WORDS( OldRebootIcons)
       rc = SysDestroyObject( WORD( OldRebootIcons, i));
    END;
    SAY 'Ok.';
 END;

/*
 IF (fOpenObjects) THEN
 DO
    rc = SysOpenObject( '<WP_REBOOT_VIEW_README>', 'DEFAULT', 1);
    rc = SysOpenObject( '<WP_REBOOT_VIEW_README>', 'DEFAULT', 1);
 END;
*/


say ''
say "Installation of RsyncBackup/2 complete"
say '---------------------------------------'
say 'Note: qsinit RAM drives will be created, just delete them.'

pause

EXIT 0;


/************************************************************************
 *  Install RsyncBackup as Client                                                     
 */

InstallClient:

say 'Installing the RsyncBackup client'

address cmd 'copy Config\rsync.exe '   || BootDrive || '\mptn\bin\rsync.exe';
address cmd 'copy Config\rsyncd.motd ' || BootDrive || '\mptn\etc\rsyncd.motd';
address cmd 'copy Config\rsync.log '  || BootDrive || '\var\log\rsync.log';

say ''
say "Creating or updating The RsyncBackup objects..."
say ''

Directory = directory()

cRsync = Directory
dRsync = Directory || '\Backups'


/************************************************************************

               First, create the 'Rsync folder' object.
 
 ************************************************************************/

type="WPFolder"
title="RsyncBackup"
folder="<WP_DESKTOP>"
objid="<RSYNC_BACKUP>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";PARAMETERS=--daemon;ICONFILE="Directory"\Icons\network1.ICO;ICONNFILE=1,"Directory"\Icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Rsync Backup Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Rsync Backup Folder Shadow Object already exists!"
   end
end

/************************************************************************
 * Create or update the README 1ST object.
 */

type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs\readme.1st;"
if SysCreateObject(type, "readme.1st", folder, params, "replace") then
   say "readme.1st Shadow Object successfully created."
else do
   say "Failed on create the readme.1st Shadow Object!"
   call end
end

/************************************************************************
 * Create or update the QUICKSTART.TXT object.
 */

type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs\quickstart.txt;"
if SysCreateObject(type, "quickstart.txt", folder, params, "replace") then
   say "quickstart.txt Shadow Object successfully created."
else do
   say "quickstart.txt on create the quickstart.txt Shadow Object!"
   call end
end


/************************************************************************

                          Backups Folder                                        

 ************************************************************************/

 type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\Backups;"
if SysCreateObject(type, "Backups", folder, params, "replace") then
   say "Docs directory Shadow Object successfully created."
else do
   say "Failed on create the Docs Shadow Object!"
   call end
end


/************************************************************************

                            Backup Boot Folder 

 ************************************************************************/

type="WPFolder"
title="Backup Boot"
folder="<RSYNC_BACKUP>"
objid="<BackupBootFolder>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\zipped_files1.ICO;ICONNFILE=1,"Directory"\icons\zipped_files2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "ZipBoot Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "ZipBoot Folder Shadow Object already exists!"
   end
end

/************************************************************************
 * Create or update the ZipBootdrive program object
 */

type="WPProgram"
title="Zip Boot-Drive"
objid="<ZipBoot>"
folder="<BackupBootFolder>"
params="PROGTYPE=PM;EXENAME="Directory"\ZipBoot\ZipBoot.cmd;STARTUPDIR="Directory";OBJECTID="objid";ICONFILE="Directory"\icons\compress.ico;"
if SysCreateObject(type, title, folder, params, "update") then
   say "ZipBootdrive Program Object successfully created."
else do
   say "Failed on create the ZipBootdrive Program Object!"
   call end
end


/************************************************************************

                          Docs Directory Folder                                        

 ************************************************************************/

 type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs;"
if SysCreateObject(type, "docs", folder, params, "replace") then
   say "Docs directory Shadow Object successfully created."
else do
   say "Failed on create the Docs Shadow Object!"
   call end
end


/************************************************************************

            Create or update the LOCAL BACKUP FOLDER           

 ************************************************************************/

type="WPFolder"
title="Local Backup"
folder="<RSYNC_BACKUP>"
objid="<RS_LOCALCOPY>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\system1.ICO;ICONNFILE=1,"Directory"\icons\system2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Local Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Local copy Folder Shadow Object already exists!"
   end
end

/******* Create or update the Full folder *********/

type="WPFolder"
title="Full Copy (Sync)"
folder="<RS_LOCALCOPY>"
objid="<RsyncFullFolder>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\system1.ICO;ICONNFILE=1,"Directory"\icons\system2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Local Full Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Full Folder Shadow Object already exists!"
   end
end

say ''

/********** Create or update the Local copy scripts dir object *****/

 type="WPShadow"
folder="<RS_LOCALCOPY>"
params="SHADOWID="Directory"\Local_Scripts;"
if SysCreateObject(type, "Local_Scripts", folder, params, "replace") then
   say "Local Copy - Scripts Folder successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end


/************************************************************************

            Create or update the LOCAL FULL COPY program objects            

 ************************************************************************/

say ''
pause

type="WPProgram"
title="Local - Full copy (Sync)"
objid="<RsyncLocalFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log "BootDrive"\var\temp "dRsync"\Local\Full;TEMPLATE=YES;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Full Program Object successfully created."
else do
   say "Failed to create the Local Full copy Program Object!"
   call end
end

type="WPProgram"
title="Local copy - Home Directory"
objid="<RsyncHomeFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log "HomePath" "dRsync"\Local\Full;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Home Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Local - Full Home Directory: copy Program Object!"
   call end
end

type="WPProgram"
title="Local copy - Data Directory"
objid="<RsyncDataFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log E:\Data "dRsync"\Local\Full;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Data Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Full Data Directory: copy Program Object!"
   call end
end

type="WPProgram"
title="Local copy - Programs Directory"
objid="<RsyncProgFull>"
folder="<RsyncFullFolder>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log E:\Programs "dRsync"\Local\Full;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Local - Programs Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Local - Full Programs Directory copy Program Object!"
   call end
end

type="WPShadow"
folder="<RsyncFullFolder>"
params="SHADOWID="BootDrive"\var\log\rsync.log"
if SysCreateObject(type, "rsync.log", folder, params, "replace") then
   say "rsync.log Shadow Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end

say ''

/************************************************************************

    Create or update the NETWORK BACKUP DIRECTORY objects           

 ************************************************************************/

type="WPFolder"
title="Network Backup"
folder="<RSYNC_BACKUP>"
objid="<NetworkFolder>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\network1.ICO;ICONNFILE=1,"Directory"\icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Network copy Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Network copy Folder Shadow Object already exists!"
   end
end

/************************************************************************
 * Create or update the Network_scripts directory object.
 */

 type="WPShadow"
folder="<NetworkFolder>"
params="SHADOWID="Directory"\Network_scripts;ICONFILE="Directory"\icons\network1.ICO;"
if SysCreateObject(type, "Network_scripts", folder, params, "replace") then
   say "Network Scripts folder Shadow Object successfully created."
else do
   say "Failed on create the Network copy scripts Shadow Object!"
   call end
end

say ''

/******* Create or update the NETWORK FULL directory object *********/

type="WPFolder"
title="Full Copy (Sync)"
folder="<NetworkFolder>"
objid="<RsyncFullNetwork>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\network1.ICO;ICONNFILE=1,"Directory"\icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Network Full Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Full Folder Shadow Object already exists!"
   end
end

/******* Create or update the PARTITIONS folder *********/

type="WPFolder"
title="Backup Partitions"
folder="<NetworkFolder>"
objid="<PartitionsNetwork>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\network1.ICO;ICONNFILE=1,"Directory"\icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Network Partition Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end


/************************************************************************

 * Create or update the NETWORK - FULL COPY objects

 *************************************************************************/

say ''

type="WPProgram"
title="Network - Full Copy (Sync)"
objid="<RsyncNetworkNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log "BootDrive"\var\temp 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=YES;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Full Program Object successfully created."
else do
   say "Failed to create the Network - Full Program Object!"
   call end
end

type="WPProgram"
title="Network Copy - Data Directory"
objid="<RsyncDataNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run -aiX --os2-perms --stats --delete-during --log-file=\var\log\rsync.log E:\Data 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Data Directory: Full copy program object successfully created."
else do
   say "Failed to create the Network - Data Directory: Full Copy program object!"
   call end
end

type="WPProgram"
title="Network Copy - Home Directory"
objid="<RsyncHomeNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=--dry-run -aiX --os2-perms --stats --delete-during --log-file=\var\log\rsync.log E:\Home 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Home Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Network - Home Directory: Full Copy program object!"
   call end
end

type="WPProgram"
title="Network Copy - Programs Directory"
objid="<RsyncProgNet>"
folder="<RsyncFullNetwork>"
params="PROGTYPE=WINDOWABLEVIO;EXENAME=rsync.exe;PARAMETERS=-n -aiX --os2-perms --stats --delete-during --log-file=\var\log\rsync.log E:\Programs 192.168.1.100::RsyncBackup\WS001\Full\;TEMPLATE=;MAXIMIZED=YES;NOAUTOCLOSE=YES;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Network - Programs Directory: Full Copy program object successfully created."
else do
   say "Failed to create the Network - Programs Directory: Full Copy program object!"
   call end
end

type="WPShadow"
folder="<RsyncFullNetwork>"
params="SHADOWID="BootDrive"\var\log\rsync.log"
if SysCreateObject(type, "rsync.log", folder, params, "replace") then
   say "rsync.log Shadow Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end


/************************************************************************

    Create or update the BACKUP PARTITION objects           

 ************************************************************************/

say ''

/* RxLvmGetVolumes:
 *   Query the list of volumes.  Always returns 1.  The parameter specifies a
 *   REXX stem name which will be populated with the volume data.  stem.0
 *   contains the number of volumes, and each other stem item contains the
 *   following information:
 *   <handle> <letter> <preference> <filesystem> <size> <device> <type> <bootable> <name>
 *     <handle>     An 8-digit hexadecimal string that uniquely identifies the
 *                  volume
 *     <letter>     The volume's current drive letter, or ? if none
 *     <preference> The volume's preferred drive letter, '?' if none, or '*' if the
 *                  drive letter is not assigned by LVM
 *     <filesystem> The volume's current file system
 *     <size>       The volume's size, in MiB
 *     <device>     The volume's device type.  This will be one of:
 *                      HDD - Hard disk drive
 *                      PRM - Removeable media under LVM control
 *                      CD  - CD/DVD drive (not controlled by LVM)
 *                      LAN - LAN drive (not controlled by LVM)
 *                      ?   - Unknown non-LVM device (e.g. RAM disk)
 *     <type>       The volume type.  This will be one of:
 *                      0   - standard (i.e. "compatibility") volume
 *                      1   - advanced (i.e. "LVM") volume
 *     <bootable>   The volume's bootable flag.  This will be one of:
 *                      B   - bootable (on Boot Manager menu)
 *                      S   - startable
 *                      I   - installable
 *                      N   - none
 *     <name>       The volume's name (may contain spaces or punctuation marks)
 *
 *   Example:
 *      volumes.0 == 4
 *      volumes.1 == "FC04D5A7 C C HPFS 2047 HDD 0 B eComStation"
 *      volumes.2 == "FC04D4E7 D D FAT16 2000 HDD 0 B Maintenance"
 *      volumes.3 == "FC04C567 E E JFS 102404 HDD 1 N Applications"
 *      volumes.4 == "FC04B0C7 H * CDFS 527 CD 0 N [ CDROM 1 ]"
 */
qv = RxLvmGetVolumes("vols.")
IF LEFT( qv, 6 ) == 'ERROR:' THEN DO
    PARSE VAR qv 'ERROR: ' lvm_error
    SAY 'LVM.DLL returned error code' lvm_error
    RETURN lvm_error
END
SAY vols.0 'volumes found:'
DO i = 1 TO vols.0
    PARSE VAR vols.i vhandle vletter vpref vfilesys vsize vdevice vtype vbootable vname
    IF vletter == '?'        THEN letter = '--'
    ELSE IF vpref \= vletter THEN letter = vpref'->'vletter':'
    ELSE                          letter = vletter':'
    IF vtype == 1 THEN type = 'Advanced volume'
    ELSE               type = 'Standard volume'
    SELECT
        WHEN vbootable == 'S' THEN boot = 'Startable'
        WHEN vbootable == 'I' THEN boot = 'Installable'
        WHEN vbootable == 'B' THEN boot = 'Bootable'
        OTHERWISE                  boot = ''
    END
    SAY RIGHT( letter, 6 ) LEFT( vname, 20 ) LEFT( vfilesys, 10 ) LEFT( vsize 'MB', 14 ) vdevice ' ' boot
    SAY '      ' type '['vhandle']'

END
SAY
    pause


 /* show help */
 ARG Parm .
 IF (POS('?', Parm) > 0) THEN
 DO
    rc = ShowHelp();
    EXIT(ERROR.INVALID_PARAMETER);
 END;

 /* defaults */
 GlobalVars = GlobalVars 'Partition.';
 fOpenObjects = (POS(Parm, '/BATCH') \= 1);

 /* load rexxutils */
 Call RxFuncAdd 'SysLoadFuncs','REXXUTIL','SysLoadFuncs';
 Call SysLoadFuncs;

 PARSE SOURCE . . CallName
 CallPath = LEFT( CallName, LASTPOS( '\', CallName) - 1);
 IconPath = CallPath;

 /* query system version */
 IF (SysOs2Ver() < 2.40) THEN
    FolderIconBase = IconPath'\folder3';
 ELSE
    FolderIconBase = IconPath'\folder4';

 /* determine bartitions from fdisk */
 rc = RxLvmGetVolumes("vols.")

 /* create objects */
 CALL CHAROUT, 'Creating folder for reboot objects ... ';
 rc = SysCreateObject( 'WPFolder', 'Backup Partitions', '<RS_LOCALCOPY>',  'CCVIEW=NO;OBJECTID=<RS_PARTITIONS>;ICONFILE='Directory'\Icons\system1.ICO;ICONNFILE=1,'Directory'\Icons\system2.ICO;', 'U');

 CALL CHAROUT, 'Creating program icons ... ';
 rc = SysCreateObject( 'WPProgram',  'Recreate Volume Icons ', '<RS_PARTITIONS>',  'OBJECTID=<WP_BACKUP_RECREATE>;EXENAME='CallName';PARAMETERS=/BATCH;PROGRAMTYPE=WINDOWABLEVIO;MAXIMIZED=YES;NOAUTOCLOSE=YES;', 'U');
 rc = SysCreateObject( 'WPProgram',  'Backup/2 Readme',        '<RS_PARTITIONS>',  'OBJECTID=<WP_BACKUP_VIEW_README>;CCVIEW=NO;EXENAME=E.EXE;PARAMETERS='Directory'\docs\readme_backup_partitions.txt;PROGRAMTYPE=PM;', 'U');
 SAY 'Ok.';

 /* collect ids from old reboot icons */
 OldRebootIcons = '';
 IdList = SysIni(, 'PM_Workplace:Location', 'ALL:', 'Id.');
 DO i = 1 TO Id.0
    IF (POS( '<WP_REBOOT_PART_', Id.i) = 1) THEN
       OldRebootIcons = OldRebootIcons Id.i;
 END;


 /* select partition icon */
 /* first check name */
 /* second, check partition type */
 DO i = 1 TO vols.0
    PARSE VAR vols.i vhandle vletter vpref vfilesys vsize vdevice vtype vbootable vname

    ThisPartition = TRANSLATE(vols.i);
    SELECT

       WHEN (vols.vfilesys = '83') THEN
          PartitionIcon = IconPath'\linux.ico';

       WHEN (POS('OS2', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\Icons\os2.ico';

       WHEN (POS('JFS', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\Icons\os2.ico';

       WHEN (POS('WIN', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\win.ico';

       WHEN (POS('NT', ThisPartition) > 0) THEN
          PartitionIcon = IconPath'\win.ico';

       /* assume type 7 is HPFS and not NTFS ;-) */
       WHEN (vfilesys = 'JFS') THEN
          PartitionIcon = IconPath'\Icons\os2.ico';

       OTHERWISE
          PartitionIcon = IconPath'\dos.ico';

    END;

    IF (vdevice = 'HDD') THEN
      DO 

        CALL CHAROUT, 'Creating Local backup objects for partition' vname '... ';
        Id = '<RS_PART_'TRANSLATE(TRANSLATE(vname, '_', ' '))'>';
        rc = SysCreateObject( 'WPProgram',  'Backup' '('vletter ':) ' vname , '<RS_PARTITIONS>',  'OBJECTID='Id';EXENAME=*;PARAMETERS=/C rsync --dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log 'vletter':\ 'Directory'\Backups\Local\Partitions\'vletter';PROGTYPE=WINDOWABLEVIO;MINIMIZED=YES;ICONFILE='PartitionIcon';', 'U');
    SAY 'Ok.';
      END

    IF (vdevice = 'HDD') THEN
      DO 

        CALL CHAROUT, 'Creating Netowrk backup objects for partition' vname '... ';
        Id = '<RS_NETWORK_'TRANSLATE(TRANSLATE(vname, '_', ' '))'>';
        rc = SysCreateObject( 'WPProgram',  'Network Backup' '('vletter ':) ' vname , '<PartitionsNetwork>',  'OBJECTID='Id';EXENAME=rsync.exe;PARAMETERS=--dry-run --archive --itemize-changes --os2-perms --stats --xattrs --delete-during --log-file=\var\log\rsync.log 'vletter':\ 192.168.1.100::RsyncBackup\WS001\Partitions\'vletter';PROGTYPE=WINDOWABLEVIO;MINIMIZED=YES;ICONFILE='PartitionIcon';', 'U');
    SAY 'Ok.';
      END

    /* don't delete that one later */
    IdPos = WORDPOS( Id, OldRebootIcons);
    IF (IdPos > 0) THEN
    DO
       OldRebootIcons = DELWORD( OldRebootIcons, IdPos, 1);
    END;


 END;

 /* delete old reboot icons */
 IF (WORDS( OldRebootIcons) > 0) THEN
 DO

    CALL CHAROUT, 'Deleting obsolete program icons ... ';
    DO i = 1 TO WORDS( OldRebootIcons)
       rc = SysDestroyObject( WORD( OldRebootIcons, i));
    END;
    SAY 'Ok.';
 END;

/*
 IF (fOpenObjects) THEN
 DO
    rc = SysOpenObject( '<WP_REBOOT_VIEW_README>', 'DEFAULT', 1);
    rc = SysOpenObject( '<WP_REBOOT_VIEW_README>', 'DEFAULT', 1);
 END;
*/


say "Installation of RsyncBackup/2 complete"
say '--------------------------------------'

pause


EXIT 0;




/************************************************************************
 *
 *  Install RsyncBackup as Server
 *                                                    
 ************************************************************************/

InstallServer:

say 'Install RsyncBackup server'
pause

address cmd 'copy Config\rsync.exe '   || BootDrive || '\mptn\bin\rsync.exe';
address cmd 'copy Config\rsyncd.motd ' || BootDrive || '\mptn\etc\rsyncd.motd';
address cmd 'copy Config\rsyncd.log '  || BootDrive || '\var\log\rsyncd.log';

say "Creating or updating the RsyncBackup program objects..."


Directory = directory()

cRsync = Directory
dRsync = Directory || '\Backups'


/************************************************************************

               First, create the 'RsyncBackup folder' object.
 
 ************************************************************************/

type="WPFolder"
title="RsyncBackup"
folder="<WP_DESKTOP>"
objid="<RSYNC_BACKUP>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";PARAMETERS=--daemon;ICONFILE="Directory"\Icons\network1.ICO;ICONNFILE=1,"Directory"\Icons\network2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Rsync Backup Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Rsync Backup Folder Shadow Object already exists!"
   end
end

/**********************************************
 * Create or update the README 1ST object.
 */

type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs\readme.1st;"
if SysCreateObject(type, "readme.1st", folder, params, "replace") then
   say "readme.1st Shadow Object successfully created."
else do
   say "Failed on create the readme.1st Shadow Object!"
   call end
end

/**********************************************
 * Create or update the QUICKSTART.TXT object.
 */

type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs\quickstart.txt;"
if SysCreateObject(type, "quickstart.txt", folder, params, "replace") then
   say "quickstart.txt Shadow Object successfully created."
else do
   say "quickstart.txt on create the quickstart.txt Shadow Object!"
   call end
end


/************************************************************************

                            Backup Boot Folder 

 ************************************************************************/

type="WPFolder"
title="Backup Boot"
folder="<RSYNC_BACKUP>"
objid="<BackupBootFolder>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\icons\zipped_files1.ICO;ICONNFILE=1,"Directory"\icons\zipped_files2.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Other Backups Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Other Backups Folder Shadow Object already exists!"
   end
end

/***************************************************
 * Create or update the ZipBootdrive program object
 */

type="WPProgram"
title="Zip Boot-Drive"
objid="<ZipBoot>"
folder="<BackupBootFolder>"
params="PROGTYPE=PM;EXENAME="Directory"\ZipBoot\ZipBoot.cmd;STARTUPDIR="Directory";OBJECTID="objid";ICONFILE="Directory"\icons\compress.ico;"
if SysCreateObject(type, title, folder, params, "update") then
   say "ZipBootdrive Program Object successfully created."
else do
   say "Failed on create the ZipBootdrive Program Object!"
   call end
end


/************************************************************************

                          Docs Directory Folder                                        

 ************************************************************************/

 type="WPShadow"
folder="<RSYNC_BACKUP>"
params="SHADOWID="Directory"\docs;"
if SysCreateObject(type, "docs", folder, params, "replace") then
   say "Docs directory Shadow Object successfully created."
else do
   say "Failed on create the Docs Shadow Object!"
   call end
end



/************************************************************************

                          Rsync Server Folder                                        

 ************************************************************************/

say ''
type="WPFolder"
title="Rsync Server"
folder="<RSYNC_BACKUP>"
objid="<Rsync_Server>"
params="BACKGROUND="BootDrive"\OS2\BITMAP\altgry01.bmp,T,,I,0 0 0;ICONVIEWPOS=10,35,60,40;ICONFONT=9.WarpSans Bold;ICONTEXTCOLOR=0 0 64;ICONSHADOWCOLOR=0 0 255;ICONVIEW=FLOWED;OBJECTID="objid";ICONFILE="Directory"\Icons\network3.ICO;ICONNFILE=1,"Directory"\Icons\network4.ICO;"
if SysCreateObject(type, title, folder, params, "fail") then
   say "Rsync Server Folder Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Rsync Server Folder Shadow Object already exists!"
   end
end

/*******************************************************
 * Create or update the Rsync Server program object
 */

type="WPProgram"
title="Rsync Server"
objid="<RsyncProgram>"
folder="<Rsync_Server>"
params="PROGTYPE=PM;EXENAME="BootDrive"\mptn\bin\rsync.exe;PARAMETERS=--daemon --config="Directory"\Config\rsyncd.conf --log-file="BootDrive"\var\log\rsyncd.log;OBJECTID="objid";STARTUPDIR="BootDrive"\mptn\bin;ICONFILE="Directory"\icons\system.ICO;"
if SysCreateObject(type, title, folder, params, "update") then
   say "Rsync Server Object successfully created."
else do
   say "Failed on create the Rsync Program Object!"
   call end
end

/*******************************************************
 * Create or update the edit rsyncd.conf program object
 */

type="WPProgram"
title="edit rsyncd.conf"
objid="<RsyncEdit>"
folder="<Rsync_Server>"
params="PROGTYPE=PM;EXENAME=e.exe;PARAMETERS="Directory"\Config\rsyncd.conf;OBJECTID="objid";"
if SysCreateObject(type, title, folder, params, "update") then
   say "Rsync Config Object successfully created."
else do
   say "Failed on create the Rsync Program Object!"
   call end
end

/*******************************************************
 * Create or update the rsyncd.log program object
 */

type="WPShadow"
folder="<Rsync_Server>"
params="SHADOWID="BootDrive"\var\log\rsyncd.log"
if SysCreateObject(type, "rsyncd.log", folder, params, "replace") then
   say "rsyncd.log Shadow Object successfully created."
else do
   type="WPShadow"
   params="SHADOWID="objid";"
   if SysCreateObject(type, title, folder, params, "fail") then do
      say "Copy Folder Shadow Object already exists!"
   end
end


"pause"

 EXIT(ERROR.NO_ERROR);

/* ------------------------------------------------------------------------- */
HALT:
 SAY 'Abbruch durch Benutzer.';
 EXIT(ERROR.GEN_FAILURE);

/* ------------------------------------------------------------------------- */
ShowHelp: PROCEDURE EXPOSE (GlobalVars)


 PARSE SOURCE . . ThisFile

 DO i = 1 TO 3
    rc = LINEIN(ThisFile);
 END;

 ThisLine = LINEIN(Thisfile);
 DO WHILE (ThisLine \= ' */')
    SAY SUBSTR(ThisLine, 7);
    ThisLine = LINEIN(Thisfile);
 END;

 rc = LINEOUT(Thisfile);

 RETURN('');


/* ========================================================================= */
QueryPartitions: PROCEDURE EXPOSE (GlobalVars)

 /* initialize */
 DROP(Partition.);
 Partition.  = '';
 Partition.0 = 0;
 i = 0;

 /* create private rexx queue */
 QueueName = RXQUEUE('CREATE');
 rc        = RXQUEUE('SET', QueueName);

 /* read fdisk data and determine bootable partitions */
 'lvm /query | rxqueue' Queuename
 DO WHILE (QUEUED() > 0)
    PARSE PULL Line;
    IF (DATATYPE( SUBSTR(Line, 38, 1)) = 'NUM') THEN
    DO
       PARSE VAR Line . +6 PartitionName +8 . . PartitionType PartitionStatus .
       IF ((PartitionStatus = 1) | (PartitionStatus = 3)) THEN
       DO
          i                = Partition.0 + 1;
          vols.i      = PartitionName;
          vols.i.type = PartitionType;
          Partition.0      = i;
       END;
    END;
 END;

 /* reset to default queue */
 rc = RXQUEUE('DELETE', QueueName);
 rc = RXQUEUE('SET', 'SESSION');

 RETURN('');


OS2BootDrive: procedure
    BootDrive = substr( value( 'RUNWORKPLACE' ,, 'ENVIRONMENT' ), 1, 2 )

    if BootDrive = '' then
        BootDrive = substr( value( 'COMSPEC' ,, 'ENVIRONMENT' ), 1, 2 )

    if length( BootDrive ) = 0 then
        BootDrive = 'C:'
Return BootDrive

